<?php
/**
 * This file is part of
 * pragmaMx - Web Content Management System.
 * Copyright by pragmaMx Developer Team - http://www.pragmamx.org
 *
 * pragmaMx is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * $Revision: 499 $
 * $Author: PragmaMx $
 * $Date: 2022-05-11 14:15:10 +0200 (Mi, 11. Mai 2022) $
 */

defined('mxMainFileLoaded') or die('access denied');

/**
 * Definition der jeweiligen Platzhalter und deren Ersetzungen
 */
function theme_define_placeholders()
{
    $part[] = array("{NAVBAR}", theme_get_navbars());
    $part[] = array("{FOOTMESSAGE}", theme_show_footmsg());
    $part[] = array("{DEBUGSERVICE}", theme_get_servicetext('debugservice'));
    $part[] = array("{DEBUGINFO}", theme_get_debuginfo());
    $part[] = array("{SITESERVICE}", theme_get_servicetext('siteservice'));
    $part[] = array("{LANGUAGEFLAGS}", theme_show_languageflags());
    $part[] = array("{CURRENTPATH}", theme_show_currentpath());
    $part[] = array("{LOGINFORM}", mx_theme_loginform());
    $part[] = array("{VIEWBENCH}", ''); // mxViewBench();
    /* versch. weitere Platzhalter */
    // $part[] = array("{SHOWDATE}", theme_show_date());
    // $part[] = array("{SHOWTIME}", theme_show_time());
    // $part[] = array("{SHOWTOTALUSER}", theme_total_user_online());
    // $part[] = array("{LOGINFORM_FIELDS}", mxGetUserLoginCheckField());
    // Banner anzeigen
    // $part[] = array("{BANNER1}",   theme_show_banner(1)         ); #HeaderBanner
    // $part[] = array("{BANNER2}",   theme_show_banner(2)         ); #FooterBanner
    // $part[] = array("{BANNER7}",   theme_show_banner(7)         ); # Skyscraper
    // $part[] = array("{BANNER6}",   theme_show_banner(6)         ); # rechter Banner
    // weitere Beispiele dazu
    return $part;
}

/**
 * Definition der einzelnen Blockbereiche
 */
function theme_define_blocks()
{
    global $themesetting;
    static $var;
    if (isset($var)) return $var;
    // linke Bloecke
    $name = 'block_left';
    $var[$name]['container'] = 'blocks_left_loop';
    $var[$name]['function'] = 'themesidebox';
    $var[$name]['position'] = 'l';
    /* einfache Moeglichkeit, die linken Bloecke bei bestimmten Seiten zu entfernen */
    if (theme_hideleftblocks() && MX_MODULE != 'admin') {
        unset($var[$name]);
    }
    // obere Center-Bloecke
    $name = 'block_center_top';
    $var[$name]['container'] = 'blocks_center_top_loop';
    $var[$name]['function'] = 'thememiddlebox';
    $var[$name]['position'] = 'c';
    // untere Center-Bloecke
    $name = 'block_center_down';
    $var[$name]['container'] = 'blocks_center_down_loop';
    $var[$name]['function'] = 'thememiddlebox';
    $var[$name]['position'] = 'd';
    // rechte Bloecke
    $name = 'block_right';
    $var[$name]['container'] = 'blocks_right_loop';
    $var[$name]['function'] = 'themesidebox';
    $var[$name]['position'] = 'r';
    return $var;
}

/**
 * Definition des Contentbereiches inkl. der open/close-Table Funktionen
 */
function theme_define_content()
{
    static $var;
    if (isset($var)) return $var;
    // die Funktion OpenTable()
    $var['opentabs']['OpenTable']['templatevar'] = 'opentable';
    $var['opentabs']['OpenTable']['innerreplace'] = '{OPENCLOSE_TABLE}'; // hier kann irgendwas stehen, es muss aber mit dem entsprechenden Text innerhalb der template-Datei uebereinstimmen...
    // die Funktion OpenTable2()
    $var['opentabs']['OpenTable2']['templatevar'] = 'opentable2';
    $var['opentabs']['OpenTable2']['innerreplace'] = '{OPENCLOSE_TABLE_2}';
    // die Funktion OpenTableAl()
    $var['opentabs']['OpenTableAl']['templatevar'] = 'opentableal';
    $var['opentabs']['OpenTableAl']['innerreplace'] = '{OPENCLOSE_TABLE_AL}';
    // die Funktion themeindex() / News Modul
    $var['themeindex'] = 'themeindex';
    // die Funktion themearticle() / News Modul
    $var['themearticle'] = 'themearticle';
    // der Name (output_container) darf nicht veraendert werden !!
    $var['output_container'] = 'script_output';
    // der Name (index_on_container) darf nicht veraendert werden !!
    $var['index_on_container'] = 'blocks_right_container';
    $var['index_on_block_container'] = 'blocks_right_loop';
    // der Name (more_header) darf nicht veraendert werden !!
    $var['add_header'] = 'more_header';

    return $var;
}

/**
 * ersetzen von eigenen Theme-Elementen, kann veraendert und ergaenzt werden
 * diese Teile werden gleich zu Beginn des scriptes, beim einlesen des templates, ersetzt
 * Vorsicht, wenn das Theme gecached werden soll!!!
 * Dann duerfen hier keine dynamischen Elemente eingesetzt werden.
 */
function theme_replace_start($template)
{
    /**
     * bestimmte Texte, vor allem Image-Pfade, die ersetzt werden sollen, definieren (suche/ersetze)
     */
    $part[] = array('"style/', '"' . MX_THEME_DIR . '/style/'); // die Stylesheets
    $part[] = array('"images/', '"' . MX_THEME_DIR . '/images/'); // normale images im theme
    // $part[] = array('url(images/', 'url(' . MX_THEME_DIR . '/images/');
    // $part[] = array('"js/', '"' . MX_THEME_DIR . '/js/');
    // Siteservicebereich entfernen, wenn Siteservice abgeschaltet oder leer ist
    if (!theme_get_servicetext('siteservice')) {
        theme_extract_optional_part($template, 'siteservice', '');
    }
    // Debugbereich entfernen, wenn Debugmodus abgeschaltet oder leer ist
    if (!theme_get_servicetext('debugservice')) {
        theme_extract_optional_part($template, 'debugservice', '');
    }
    // das Kopfmenue durch die tatsaechlichen Daten ersetzen
    theme_extract_optional_part($template, 'headmenue', '{NAVBAR}');

    return theme_replace_parts($template, $part);
}

/**
 * ersetzen von eigenen Theme-Elementen, kann veraendert und ergaenzt werden
 * diese Teile werden vor der Ausgabe des headers im Headbereich ersetzt
 */
function theme_replace_header($newheader)
{
    return $newheader;
}

/**
 * ersetzen in jedem einzelnen Block
 */
function theme_replace_blocks($template, $block)
{
    /*
    switch ($block['position']) {
        case 'l':
            break;
        case 'c':
            break;
        case 'd':
            break;
        case 'r':
            break;
    }
    */

    /* Teil fuer alle Bloecke */
    if (empty($block['title']) || $block['title'] == 'NOTITLE') {
        $part[] = array('__BLOCK_ID__' , '__BLOCK_ID__ block-hide-caption');
    }
    $part[] = array('__BLOCK_ID__' , 'block-' . $block['position'] . '-' . $block['order']);

    if (isset($part)) {
        return theme_replace_parts($template, $part);
    }
    return $template;
}

/**
 * ersetzen von eigenen Theme-Elementen, kann veraendert und ergaenzt werden
 * diese Teile werden am Ende des scriptes, in der Funktion themefooter() ersetzt
 */
function theme_replace_end($template)
{
    global $themesetting;

    /* einfache Moeglichkeit, die linken Bloecke bei bestimmten Seiten zu entfernen */
    if (theme_hideleftblocks()) {
        theme_extract_part($template, 'blocks_left_container');
    }

    return $template;
}

/**
 * pruefen ob linke Bloecke ausgeblendet werden sollen
 */
function theme_hideleftblocks()
{
    global $themesetting;
    return (isset($themesetting['noblock']) && in_array(1, $themesetting['noblock']));
}

/**
 * Die Navigationsbuttons in der Artikelliste des Newsmoduls
 */
function getThemeIndexButtons($story)
{
    global $theme_template;
    static $img, $isnewsadmin;
    if (!isset($isnewsadmin)) {
        $isnewsadmin = mxGetAdminPref('radminarticle');
    }
    if (empty($img)) {
        // die images werden in einen statischen Variable gehalten um die Bildgroessen nicht bei jedem Artikel zu ermitteln
        // xx als alttext wird weiter unten dynamisch ersetzt
        $img[1] = mxCreateImage(MX_THEME_DIR . '/images/buttons/informant.gif', 'xx', array('title' => 'xx'));
        $img[2] = mxCreateImage(MX_THEME_DIR . '/images/buttons/print.gif', _BMXPRINTER, array('title' => _BMXPRINTER));
        $img[3] = mxCreateImage(MX_THEME_DIR . '/images/buttons/friend.gif', _BMXFRIEND, array('title' => _BMXFRIEND));
        $img[4] = mxCreateImage(MX_THEME_DIR . '/images/buttons/counter.gif', 'xx', array('title' => 'xx'));
        $img[6] = mxCreateImage(MX_THEME_DIR . '/images/buttons/bytesmore.gif', 'xx', array('title' => 'xx'));
        if ($GLOBALS['articlecomm']) $img[5] = mxCreateImage(MX_THEME_DIR . '/images/buttons/comments.gif', 'xx', array('title' => 'xx'));
        // mxdebugfuncvars($story['allmorelink']); // zum ansehen der morelink-Parameter einkommentieren
        // mxdebugfuncvars($story);                // zum ansehen der story-Parameter der ersten story einkommentieren
    }
    // mxdebugfuncvars($story);                  // zum ansehen der story-Parameter aller stories einkommentieren
    $bmore = ($story['allmorelink']['bodycount']) ? _READMORE . " (" . $story['allmorelink']['bodycount'] . ' ' . _BYTESMORE . ")" : _READMORE;
    $adminlink = ($isnewsadmin) ? " href='" . adminUrl("News", "EditStory", "sid=" . $story['sid']) . "' " : "";
    $link[] = $story['allmorelink']['storylink'] . str_replace("xx", $bmore, $img[6]) . "</a>";
    if ($story['informant'] != $GLOBALS['anonymous'] && (MX_IS_USER || MX_IS_ADMIN)) {
        $link[] = $story['allmorelink']['informantlink'] . str_replace("xx", _USERINFO . ": " . $story['informant'], $img[1]) . "</a>";
    }
    $link[] = $story['allmorelink']['printerlink'] . $img[2] . "</a>";
    if (mxModuleAllowed('Recommend_Us')) {
        $link[] = $story['allmorelink']['friendlink'] . $img[3] . "</a>";
    }
    if (empty($story['acomm']) && $GLOBALS['articlecomm']) { // Achtung!!! acomm: 0 = Ja , 1 = Nein
        $link[] = $story['allmorelink']['commentslink'] . str_replace("xx", _COMMENTS . " (" . $story['comments'] . ")", $img[5]) . "</a>";
    }
    $link[] = "<a title='" . $story['allmorelink']['counter'] . ", " . $story['allmorelink']['score'] . "' " . $adminlink . ">" . str_replace("xx", $story['counter'] . ' ' . _READS, $img[4]) . "</a>";
    return $link;
}

/* die Navigationsbuttons im header, Quelle in settings.php */
function theme_get_navbars()
{
    global $themesetting;
    foreach ($themesetting['headnav'] as $title => $menue) {
        if (empty($current) && in_array(1, $menue['case'])) {
            $current = ' class="current"';
        } else {
            $current = '';
        }
        $part[] = '<li' . $current . '><a href="' . $menue['link'] . '">' . $title . '</a></li>';
    }
    // mxDebugFuncVars($themesetting, $part);
    return implode("\n", $part);
}

/**
 * Beschreibung
 */
function mx_theme_loginform()
{
    global $prefix, $user_prefix, $JPCACHE_ON;
    if ($JPCACHE_ON) {
        return;
    }
    $out = "";
    if (!MX_IS_USER) {
        if (!defined("mxloginblockviewed")) define("mxloginblockviewed", true);
        $nickname = _THEME_LOGINNICK;
        $password = _THEME_LOGINPASS;
        $login = _THEME_LOGIN;
        $check = mxGetUserLoginCheckField();
        $out .= <<<logform
<form action="modules.php?name=Your_Account" method="post">
$check
  <table cellspacing="0" cellpadding="1">
    <tbody>
      <tr>
        <td><label for="login-uname">$nickname:</label></td>
        <td><input type="text" id="login-uname" name="uname" size="14" maxlength="25" title="$nickname" /></td>
      </tr>
      <tr>
        <td><label for="login-pass">$password:</label></td>
        <td><input type="password" id="login-pass" name="pass" size="14" title="$password" /></td>
      </tr>
      <tr>
        <td>&nbsp;</td>
        <td><input name="submit" id="login-submit" type="submit" value="$login" /></td>
      </tr>
    </tbody>
  </table>

</form>
logform;
    } else {
        $hallo = _THEME_HELLO;
        $logout = _THEME_LOGOUT;
        $account = _THEME_ACCOUNT;
        $privatemessages = '';
        $username = mxSessionGetVar('user_uname');
        // private Nachrichten
        if (mxModuleAllowed('Private_Messages')) { // falls pm-modul aktiv ist
            $qry = "SELECT count(msg_id) FROM ${prefix}_priv_msgs WHERE to_userid=" . (int)mxSessionGetVar('user_uid') . " AND read_msg=0;";
            $result = sql_query($qry);
            list($count) = sql_fetch_row($result);
            if ($count) { // wenn angemeldeter User
                $privatemessages = '<p>' . sprintf((($count == 1) ? _THEME_MSGPM : _THEME_MSGSPM), $count) . '</p>';
            }
        }
        // Usergaestebuch
        $guestbook = '';
        if (mxModuleAllowed('UserGuest')) { // falls gaestebuch vorhanden
            $qry = "SELECT count(gid) FROM ${prefix}_userguest WHERE touserid=" . mxSessionGetVar('user_uid') . " AND touser = '" . $username . "' AND dummy=0;";
            $result = sql_query($qry);
            list($count) = sql_fetch_row($result);
            if ($count) {
                $guestbook = '<p>' . sprintf((($count == 1) ? _THEME_MSGUG : _THEME_MSGSUG), $count) . '</p>';
            }
        }

        $arrowpic = mxCreateImage(MX_THEME_DIR . '/images/arrow.gif', '');
        $out .= <<<logform
<div class="hello">
<p>$hallo <b>$username</b> !</p>
$privatemessages
$guestbook
  <ul>
    <li><a href="modules.php?name=Your_Account" title="$account">$account</a></li>
    <li><a href="modules.php?name=Your_Account&amp;op=logout" title="$logout">$logout</a></li>
  </ul>

</div>
logform;
    }
    return $out;
}

/**
 * in $newheader ist der gesamte angepasste header enthalten
 */
function theme_header($newheader, &$siteservice, &$debugservice)
{
    global $theme_template, $themesetting;
    /* das Theme verwendet eigene Servicebereiche, deswegen hier die beiden Variablen killen */
    $siteservice = null;
    $debugservice = null;
    /* den body-Tag hinter head-Ende setzen >> nicht veraendern !! */
    $newheader .= "\n</head>\n\n" . $theme_template['body_tag'] . "\n\n";
    // ersetzen von eigenen Theme-Elementen, kann veraendert und ergaenzt werden
    // diese Teile werden vor der Ausgabe des headers im Headbereich ersetzt
    $newheader = theme_replace_header($newheader);

    return $newheader;
}

/**
 * parsen der Seiten-Bloecke
 */
function themesidebox($title, $content, $block = array(), $noecho = 0)
{
    global $theme_template;
    if (empty($block)) {
        $block['position'] = "l";
    }
    $out = ($block['position'] == "r") ? $theme_template['block_right'] : $theme_template['block_left'];
    $out = str_replace('{BLOCK_CONTENT}' , $content , $out);
    $out = str_replace('{BLOCK_TITLE}' , $title , $out);
    if ($noecho) {
        return $out;
    } else {
        echo $out;
    }
}

/**
 * parsen der Center-Bloecke
 */
function thememiddlebox($title, $content, $block = array(), $noecho = 0)
{
    global $theme_template;
    if (empty($block)) {
        $block['position'] = "c";
    }
    $out = ($block['position'] == "d") ? $theme_template['block_center_down'] : $theme_template['block_center_top'];
    $out = str_replace('{BLOCK_CONTENT}' , $content , $out);
    $out = str_replace('{BLOCK_TITLE}' , $title , $out);
    if ($noecho) {
        return $out;
    } else {
        echo $out;
    }
}

/**
 * News Modul Artikelliste (index.php)
 * $x bedeutet: nicht verwendet, nur zur nuke-Modulkompatibilitaet
 */
function themeindex($x1, $x2, $x3, $x4, $x5, $x6, $x7, $x8, $x9, $x10, $x11, $x12, $story = array())
{
    global $theme_template;
    static $viewcounter;
    if (!isset($viewcounter) || ($viewcounter == 2)) $viewcounter = 0;
    $viewcounter++;
    pmxHeader::add_style('themes/' . basename(dirname(__FILE__)) . '/style/news.css');
    $story['buttons'] = implode('</li><li>', getThemeIndexButtons($story));
    $bmore = ($story['allmorelink']['bodycount']) ? '(' . $story['allmorelink']['bodycount'] . ' ' . _BYTESMORE . ')' : '';
    $story['readmore'] = (empty($bmore)) ? '' : '<span title="' . $bmore . '">' . $story['allmorelink']['more'] . '</span>';
    if ($GLOBALS['storyhome_cols'] == 1) {
        $topicimage_class = ($viewcounter == 1) ? 'story-topicimage-left' : 'story-topicimage-right';
        $topicimage = mxCreateImage($GLOBALS['tipath'] . $story['topicimage'], _TOPIC . ': ' . $story['topictext'], 0, 'class="' . $topicimage_class . '"');
        $story['topicimage'] = '<a href="modules.php?name=News&amp;topic=' . $story['topic'] . '">' . $topicimage . '</a>';
    } else {
        $story['topicimage'] = '';
    }
    $cattitle = (empty($story['cattitle'])) ? '' : ' <span class="story-cattitle">(' . $story['allmorelink']['categorie'] . ')</span>';
    $authorinfo = (empty($story['informant']) || $story['informant'] == $GLOBALS['anonymous']) ? theme_adminname($story) : $story['allmorelink']['informantlink'] . $story['informant'] . ((mxModuleAllowed('Userinfo') || MX_IS_ADMIN) ? '</a>' : '');
    $story['content'] = $story['hometext'];
    $story['infoline'] = ($GLOBALS['storyhome_cols'] == 1) ? _NEWSSUBMITED . ' ' . $authorinfo . ' ' . $story['allmorelink']['datetime'] : $story['datetime'];
    $story['title'] = strip_tags($story['title']) . $cattitle;
    // die oben definierten Variablen in dem passenden templateteil ersetzen
    $artvars = theme_define_content();
    echo theme_replace_vars($theme_template[$artvars['themeindex']], $story);
    return;
}

/**
 * News Modul Artikelansicht (article.php)
 * $x bedeutet: nicht verwendet, nur zur nuke-Modulkompatibilitaet
 */
function themearticle($x1, $x2, $x3, $x4, $x5, $x6, $x7, $x8, $x9, $story = array())
{
    global $theme_template;
    pmxHeader::add_style('themes/' . basename(dirname(__FILE__)) . '/style/news.css');
    // mxDebugFuncVars($story);
    // das Topic-Bild
    $topicimage = mxCreateImage($GLOBALS['tipath'] . $story['topicimage'], $story['topictext'], 0, 'align="left" style="padding-right: 20px; padding-bottom: 10px;"');
    $notes = (empty($story['notes'])) ? '' : '<div style="font-style: italic;">' . $story['notes'] . '</div>';
    $authorinfo = (empty($story['informant']) || $story['informant'] == $GLOBALS['anonymous']) ? theme_adminname($story) : $story['allmorelink']['informantlink'] . $story['informant'] . ((mxModuleAllowed('Userinfo') || MX_IS_ADMIN) ? '</a>' : '');
    $story['infoline'] = ($GLOBALS['storyhome_cols'] == 1) ? _NEWSSUBMITED . ' ' . $authorinfo . ' ' . $story['allmorelink']['datetime'] : $story['datetime'];
    $story['title'] = strip_tags($story['title']);
    $story['content'] = '<a href="modules.php?name=News&amp;topic=' . $story['topic'] . '">' . $topicimage . "</a>\n" . $story['hometext'] . "<br />\n" . $story['bodytext'] . $notes;
    // die oben definierten Variablen in dem passenden templateteil ersetzen
    echo theme_replace_vars($theme_template['themearticle'], $story);
    return;
}

?>